==> porridge_0.3.0.tgz: porridge/NEWS.Rd <==
\name{NEWS}
\title{News for Package \pkg{porridge}}
\newcommand{\cpkg}{\href{http://cran.r-project.org/package=#1}{\pkg{#1}}}

\section{Changes in version 0.3.0}{
 \itemize{
    \item Functionality of the \code{ridgeGLM} and \code{optPenaltyGLM.kCVauto} expanded. Among other, unpenalized covariates may now be supplied and a generalized penalty matrix provided.
    \item Bug fix: correct stopping criterion for the IRLS algorithm of the penalized ridge logistic regression estimator.
    \item Citations updated.
  }
}

\section{Changes in version 0.2.1}{
 \itemize{
    \item Faster implementation of the functions for target and multi-targeted ridge estimation of the GLM offered.
  }
}

\section{Changes in version 0.2.0}{
 \itemize{
    \item Reference added to the Description-file.
    \item Functions for target and multi-targeted ridge estimation of the GLM added.
  }
}

\section{Changes in version 0.1.1}{
 \itemize{
    \item Corrected DOIs in the Description field.
  }
}

\section{Changes in version 0.1.0}{
 \itemize{
    \item Restructuring of R and C++ files into modules.
    \item Novel module added.
    \item Some layout polish in the manual.
  }
}

\section{Changes in version 0.0.4}{
 \itemize{
    \item Modification of C++ code related to the \code{ridgePrepEdiag}- and \code{optPenaltyPrepEdiag}-functions. In case of an unbalanced design the initialization of EM algorithm no longer yields negative definite precisiom matrices.
  }
}

\section{Changes in version 0.0.3}{
 \itemize{
    \item Modification of input checks to meet CRAN's best practice.  
    \item Removed an accidently inserted section in the manual of the \code{optPenaltyGGMmixture.kCVauto}-function.  
  }
}

\section{Changes in version 0.0.2}{
 \itemize{
    \item The unnecessary dependency on the \code{rags2ridges}-packages has been removed. 
  }
}

\section{Changes in version 0.0.1}{
 \itemize{
    \item Release of the Urfassung. 
  }
}

==> porridge_0.3.1.tgz: porridge/NEWS.Rd <==
\name{NEWS}
\title{News for Package \pkg{porridge}}
\newcommand{\cpkg}{\href{http://cran.r-project.org/package=#1}{\pkg{#1}}}

\section{Changes in version 0.3.1}{
 \itemize{
    \item Bug fix: incorrectly placed bracket on the C++ part of the \code{ridgeGGMmixture}-function assigned to its proper spot.
    \item Extra input check in the \code{ridgePgen.kCV.groups}-function.
    \item Citations updated.
    \item To fix a note of CRAN's check results the \code{rags2ridges}- and \code{ragt2ridges}-packages are added to \code{Suggests} in the \code{Description}-file.
    \item Input checks are now performed by means the \code{inherits}-function instead of the \code{class}-function.
  }
}

\section{Changes in version 0.3.0}{
 \itemize{
    \item Functionality of the \code{ridgeGLM} and \code{optPenaltyGLM.kCVauto} expanded. Among others, unpenalized covariates may now be supplied and a generalized penalty matrix provided.
    \item Bug fix: correct stopping criterion for the IRLS algorithm of the penalized ridge logistic regression estimator.
    \item Citations updated.
  }
}

\section{Changes in version 0.2.1}{
 \itemize{
    \item Faster implementation of the functions for target and multi-targeted ridge estimation of the GLM offered.
  }
}

\section{Changes in version 0.2.0}{
 \itemize{
    \item Reference added to the Description-file.
    \item Functions for target and multi-targeted ridge estimation of the GLM added.
  }
}

\section{Changes in version 0.1.1}{
 \itemize{
    \item Corrected DOIs in the Description field.
  }
}

\section{Changes in version 0.1.0}{
 \itemize{
    \item Restructuring of R and C++ files into modules.
    \item Novel module added.
    \item Some layout polish in the manual.
  }
}

\section{Changes in version 0.0.4}{
 \itemize{
    \item Modification of C++ code related to the \code{ridgePrepEdiag}- and \code{optPenaltyPrepEdiag}-functions. In case of an unbalanced design the initialization of EM algorithm no longer yields negative definite precisiom matrices.
  }
}

\section{Changes in version 0.0.3}{
 \itemize{
    \item Modification of input checks to meet CRAN's best practice.  
    \item Removed an accidently inserted section in the manual of the \code{optPenaltyGGMmixture.kCVauto}-function.  
  }
}

\section{Changes in version 0.0.2}{
 \itemize{
    \item The unnecessary dependency on the \code{rags2ridges}-packages has been removed. 
  }
}

\section{Changes in version 0.0.1}{
 \itemize{
    \item Release of the Urfassung. 
  }
}
